@@ -148,7 +148,7 @@ class CidClient:
                                   attribute_id,
                                   value,
                                   traits,
-                                  extras,
+                                  aux,
                                   detailed_nodes_id):
         """
         :param payload: The payload to attach while requesting
@@ -164,7 +164,7 @@ class CidClient:
             "attribute_id": attribute_id,
             "value": value,
             "traits": traits,
-            "extras": extras,
+            "aux": aux,
             "detailed_nodes_id": detailed_nodes_id
         })
 
